#!/bin/bash
# SPDX-License-Identifier: MIT

# Check if the RPM SPEC file is given as an argument
if [[ $# -ne 2 ]]; then
    echo "Usage: $0 <path_to_rpm_spec_file> <espanso_version"
    exit 1
fi

RPM_SPEC_FILE=$1

# Extract the directory from the RPM SPEC file path
SPEC_DIR=$(dirname $(realpath "$RPM_SPEC_FILE"))

# Extract the URL, commit, tag, and version from the RPM SPEC file
NAME=$(awk '/^%global crate/ {print $NF}' "$RPM_SPEC_FILE")
REPO_URL="https://github.com/espanso/espanso"
EXPANSO_VERSION=$2
VERSION=$(awk '/^Version:/ {print $NF}' "$RPM_SPEC_FILE")

# Create a temporary directory and clone the repository
TMP_DIR=$(mktemp -d)
trap "rm -rf $TMP_DIR" EXIT
git clone "$REPO_URL" "$TMP_DIR"
if [[ $? -ne 0 ]]; then
    echo "Failed to clone repository."
    exit 3
fi

# Change to the directory
pushd "$TMP_DIR" > /dev/null

# Checkout based on priority: commit > tag > Version
CHECKOUT_SUCCESS=0
git checkout "$EXPANSO_VERSION" || git checkout "v$EXPANSO_VERSION"
if [ $? -eq 0 ]; then
    CHECKOUT_SUCCESS=1
fi

if [ $CHECKOUT_SUCCESS -eq 0 ]; then
    echo "Failed to checkout version."
    exit 5
fi

# copy licence
cp -aR LICENSE $NAME/.
mv $NAME $NAME-$VERSION

# Create a tar.gz of the vendor directory
tar czf "$NAME-$VERSION.tar.gz" $NAME-$VERSION/
if [[ $? -ne 0 ]]; then
    echo "Failed to create tar.gz of the vendor directory."
    exit 7
fi

# Move the tar.gz to the SPEC directory
mv "$NAME-$VERSION.tar.gz" "$SPEC_DIR/"

# Go back to the original directory
popd > /dev/null

# Clean up
rm -rf "$TMP_DIR"

echo "Created $NAME-$VERSION.tar.gz successfully."
